@@ -1,6 +1,6 @@
-/******************************************************************************
-    Xplanet 0.43 - render an image of the earth into an X window
-    Copyright (C) 1999 Hari Nair <hari@alumni.caltech.edu>
+/****************************************************************************
+    Xplanet 0.94 - render an image of a planet into an X window
+    Copyright (C) 2001 Hari Nair <hari@alumni.caltech.edu>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -15,10 +15,17 @@
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+****************************************************************************/
 
-******************************************************************************/
+#ifndef AUXFILES_H
+#define AUXFILES_H
 
-char *prefix               = "/usr/share/xplanet/";
-char *defaultmapext        = ".ppm";
-char *defaultmarkerfile    = "-markers.txt";
-char *versionstring        = "Xplanet 0.43";
+#include <string>
+using namespace std;
+
+const string prefix               = "/usr/local/share/xplanet";
+const string defaultmapext        = ".jpg";
+const string separator            = "/";
+const string versionstring        = "Xplanet 0.94";
+
+#endif
