@@ -1,6 +1,6 @@
-/******************************************************************************
-    Xplanet 0.43 - render an image of the earth into an X window
-    Copyright (C) 1999 Hari Nair <hari@alumni.caltech.edu>
+/****************************************************************************
+    Xplanet 0.94 - render an image of a planet into an X window
+    Copyright (C) 2002 Hari Nair <hari@alumni.caltech.edu>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -15,16 +15,12 @@
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+****************************************************************************/
 
-******************************************************************************/
+#ifndef XPLANET_H
+#define XPLANET_H
 
-#include <time.h>
-#include <sys/timeb.h>
+extern unsigned char *elevation;
 
-extern struct timeb tp;
-extern double sunlon, sunlat, sundist;
+#endif
 
-extern char *prefix;
-extern char *defaultmapext;
-extern char *defaultmarkerfile;
-extern char *versionstring;
